@@ -38,7 +38,7 @@ pub struct NodeAuth {
     pub section_pk: BlsPublicKey,
     /// Public key of the source peer.
     #[debug(with = "PublicKey::fmt_ed25519")]
-    pub public_key: EdPublicKey,
+    pub node_ed_pk: EdPublicKey,
     /// Ed25519 signature of the message corresponding to the public key of the source peer.
     #[debug(with = "Signature::fmt_ed25519")]
     #[serde(with = "serde_bytes")]
@@ -54,7 +54,7 @@ impl NodeAuth {
     ) -> AuthorityProof<Self> {
         AuthorityProof(NodeAuth {
             section_pk,
-            public_key: keypair.public,
+            node_ed_pk: keypair.public,
             signature: keypair.sign(payload.as_ref()),
         })
     }
@@ -162,7 +162,7 @@ impl sealed::Sealed for ServiceAuth {}
 
 impl VerifyAuthority for NodeAuth {
     fn verify_authority(self, payload: impl AsRef<[u8]>) -> Result<Self> {
-        self.public_key
+        self.node_ed_pk
             .verify(payload.as_ref(), &self.signature)
             .map_err(|_| Error::InvalidSignature)?;
         Ok(self)
