@@ -84,7 +84,7 @@ impl Node {
                 section_signed,
                 proof_chain,
                 bounced_msg,
-                sender.clone(),
+                sender,
             )
             .await?;
 
@@ -135,7 +135,8 @@ impl Node {
             .sorted_by(|lhs, rhs| target_name.cmp_distance(&lhs.name(), &rhs.name()))
             .peekable()
             .peek()
-            .map(|elder| (*elder).clone());
+            .copied()
+            .copied();
 
         let to_resend = self
             .update_network_knowledge(
@@ -143,7 +144,7 @@ impl Node {
                 section_signed,
                 section_chain,
                 bounced_msg,
-                sender.clone(),
+                sender,
             )
             .await?;
 
@@ -273,7 +274,7 @@ impl Node {
                 tokio::time::sleep(sleep_time).await;
             }
         } else {
-            let _res = ae_backoff_guard.insert((peer.clone(), ExponentialBackoff::default()));
+            let _res = ae_backoff_guard.insert((*peer, ExponentialBackoff::default()));
         }
     }
 
@@ -321,7 +322,7 @@ impl Node {
                     trace!("{}", LogMarker::AeSendRedirect);
 
                     return Ok(Some(Cmd::SendMsg {
-                        recipients: vec![sender.clone()],
+                        recipients: vec![*sender],
                         wire_msg,
                     }));
                 }
@@ -413,7 +414,7 @@ impl Node {
         )?;
 
         Ok(Some(Cmd::SendMsg {
-            recipients: vec![sender.clone()],
+            recipients: vec![*sender],
             wire_msg,
         }))
     }
